pub enum R {
Show 15 variants
Unknown(Type, Tag, Vec<u8>),
Version(Tag, u32, Version),
Auth(Tag, Qid),
Attach(Tag, Qid),
Error(Tag, String, u32),
Flush(Tag),
Walk(Tag, Vec<Qid>),
Open(Tag, Qid, u32),
Create(Tag, Qid, u32),
Read(Tag, Vec<u8>),
Write(Tag, u32),
Clunk(Tag),
Remove(Tag),
Stat(Tag, Stat),
WStat(Tag),
}Expand description
R messages are Server-to-Client messages.
Variants
Unknown(Type, Tag, Vec<u8>)
Unknown is constructed when the Type is unknown or unexpected.
Version(Tag, u32, Version)
RVersion is part of the negotiation of the connection.
Auth(Tag, Qid)
Open authentication file.
Attach(Tag, Qid)
Attach to a filesystem tree.
Error(Tag, String, u32)
Something went wrong. What went wrong?
Flush(Tag)
The command by this Tag has been flushed from the queue.
Walk(Tag, Vec<Qid>)
Walk the filesystem to a specific File, returning Qids for everything along the path.
Open(Tag, Qid, u32)
Confirmation that a specific file has been Opened.
Create(Tag, Qid, u32)
Confirmation that a specific file has been Created.
Read(Tag, Vec<u8>)
Data that was read in response to a Tag
Write(Tag, u32)
Data was confirmed to have been written.
Clunk(Tag)
File descriptor has been clunked (closed).
Remove(Tag)
File was removed.
Stat(Tag, Stat)
Information about a File
WStat(Tag)
Information about a File